@@ -1,9 +1,10 @@
-from .cli import CLI as CLI
+from .arg_types import AssertPath as AssertPath
 from .arg_types import AssertSet as AssertSet
 from .arg_types import Chain as Chain
 from .arg_types import Context as Context
 from .arg_types import Env as Env
-from .arg_types import ImportFile as ImportFile
+from .arg_types import ImportInstance as ImportInstance
+from .arg_types import ImportType as ImportType
 from .arg_types import JsonData as JsonData
 from .arg_types import JsonFile as JsonFile
 from .arg_types import Map as Map
@@ -11,4 +12,7 @@ from .arg_types import Operator as Operator
 from .arg_types import Paths as Paths
 from .arg_types import Pattern as Pattern
 from .arg_types import RawFile as RawFile
+from .cli import CLI as CLI
+from .command import command as command
+from .group import group as group
 from .help_message import CLIStyle as CLIStyle
